----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch
--
-- Module Name: scalp_packet_fifo_wrapper - arch
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.2
-- Description: scalp_packet_fifo_wrapper
--
-- Last update: 2020-11-08
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use work.axi4_pkg.all;

entity scalp_packet_fifo_wrapper is

    port (
        RdClkxCI        : in  std_logic;
        WrClkxCI        : in  std_logic;
        ResetxRI        : in  std_logic;
        NativeSlavexDI  : in  t_native_fifo_slave;
        NativeMasterxDO : out t_native_fifo_master);

end scalp_packet_fifo_wrapper;

architecture arch of scalp_packet_fifo_wrapper is

    component scalp_packet_fifo
        port (
            wr_clk       : in  std_logic;
            rd_clk       : in  std_logic;
            rst          : in  std_logic;
            din          : in  std_logic_vector((C_AXI4_DATA_SIZE - 1) downto 0);
            wr_en        : in  std_logic;
            rd_en        : in  std_logic;
            dout         : out std_logic_vector((C_AXI4_DATA_SIZE - 1) downto 0);
            full         : out std_logic;
            almost_full  : out std_logic;
            empty        : out std_logic;
            almost_empty : out std_logic;
            wr_rst_busy  : out std_logic;
            rd_rst_busy  : out std_logic);
    end component;

    signal NativeSlavexD  : t_native_fifo_slave;
    signal NativeMasterxD : t_native_fifo_master;

begin

    EntityIOxB : block is
    begin  -- block EntityIOxB

        NativeSlavexAS  : NativeSlavexD   <= NativeSlavexDI;
        NativeMasterxAS : NativeMasterxDO <= NativeMasterxD;

    end block EntityIOxB;

    ScalpPacketFifoxB : block is
    begin  -- block ScalpPacketFifoxB

        ScalpPacketFifoxI : scalp_packet_fifo
            port map (
                rst          => ResetxRI,
                wr_clk       => WrClkxCI,
                rd_clk       => RdClkxCI,
                din          => NativeSlavexD.DataxD,
                wr_en        => NativeSlavexD.WrEnxS,
                rd_en        => NativeSlavexD.RdEnxS,
                dout         => NativeMasterxD.DataxD,
                full         => NativeMasterxD.FullxS,
                almost_full  => NativeMasterxD.AlmostFullxS,
                empty        => NativeMasterxD.EmptyxS,
                almost_empty => NativeMasterxD.AlmostEmptyxS,
                wr_rst_busy  => NativeMasterxD.WrRstBusyxS,
                rd_rst_busy  => NativeMasterxD.RdRstBusyxS);

    end block ScalpPacketFifoxB;

end arch;
